@@ -11,15 +11,14 @@
 
 #include "kmanagersieve_debug.h"
 #include <KAuthorized>
+#include <KIO/AuthInfo>
+#include <KIO/Job>
+#include <KIO/SslUi>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KPasswordDialog>
 #include <QRegularExpression>
 #include <QUrlQuery>
-#include <kio/authinfo.h>
-#include <kio/job.h>
-#include <kio/sslui.h>
-#include <kwidgetsaddons_version.h>
 
 using namespace KManageSieve;
 
@@ -262,9 +261,7 @@ KManageSieve::AuthDetails Session::requestAuthDetails(const QUrl &url)
         "(usually the same as your email password):");
 
     QPointer<KPasswordDialog> dlg = new KPasswordDialog(nullptr, KPasswordDialog::ShowUsernameLine | KPasswordDialog::ShowKeepPassword);
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 84, 0)
     dlg->setRevealPasswordAvailable(KAuthorized::authorize(QStringLiteral("lineedit_reveal_password")));
-#endif
     dlg->setUsername(ai.username);
     dlg->setPassword(ai.password);
     dlg->setKeepPassword(ai.keepPassword);
@@ -276,7 +273,7 @@ KManageSieve::AuthDetails Session::requestAuthDetails(const QUrl &url)
     AuthDetails ad;
     ad.valid = false;
     if (dlg->exec()) {
-        ad.username = dlg->password();
+        ad.username = dlg->username();
         ad.password = dlg->password();
         ad.valid = true;
     }
