@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -13,12 +13,10 @@ SelectAddHeaderPositionCombobox::SelectAddHeaderPositionCombobox(QWidget *parent
     : QComboBox(parent)
 {
     initialize();
-    connect(this, QOverload<int>::of(&SelectAddHeaderPositionCombobox::activated), this, &SelectAddHeaderPositionCombobox::valueChanged);
+    connect(this, &SelectAddHeaderPositionCombobox::activated, this, &SelectAddHeaderPositionCombobox::valueChanged);
 }
 
-SelectAddHeaderPositionCombobox::~SelectAddHeaderPositionCombobox()
-{
-}
+SelectAddHeaderPositionCombobox::~SelectAddHeaderPositionCombobox() = default;
 
 void SelectAddHeaderPositionCombobox::initialize()
 {
