@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -14,12 +14,10 @@ SelectMimeComboBox::SelectMimeComboBox(QWidget *parent)
     : QComboBox(parent)
 {
     initialize();
-    connect(this, QOverload<int>::of(&SelectMimeComboBox::activated), this, &SelectMimeComboBox::valueChanged);
+    connect(this, &SelectMimeComboBox::activated, this, &SelectMimeComboBox::valueChanged);
 }
 
-SelectMimeComboBox::~SelectMimeComboBox()
-{
-}
+SelectMimeComboBox::~SelectMimeComboBox() = default;
 
 void SelectMimeComboBox::initialize()
 {
