@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,9 +7,9 @@
 #include "sievescripttabwidget.h"
 #include "sievewidgetpageabstract.h"
 
-#include <QMenu>
 #include <KLocalizedString>
 #include <QIcon>
+#include <QMenu>
 
 #include <QTabBar>
 
@@ -25,9 +25,7 @@ SieveScriptTabWidget::SieveScriptTabWidget(QWidget *parent)
     connect(this, &SieveScriptTabWidget::customContextMenuRequested, this, &SieveScriptTabWidget::slotTabContextMenuRequest);
 }
 
-SieveScriptTabWidget::~SieveScriptTabWidget()
-{
-}
+SieveScriptTabWidget::~SieveScriptTabWidget() = default;
 
 void SieveScriptTabWidget::slotTabContextMenuRequest(const QPoint &pos)
 {
@@ -38,7 +36,7 @@ void SieveScriptTabWidget::slotTabContextMenuRequest(const QPoint &pos)
         return;
     }
 
-    auto *page = qobject_cast<SieveWidgetPageAbstract *>(w);
+    auto page = qobject_cast<SieveWidgetPageAbstract *>(w);
     if (!page) {
         return;
     }
