@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -92,7 +92,7 @@ public Q_SLOTS:
     void slotCheckSyntax();
     void comment();
     void uncomment();
-    void wordWrap(bool state);
+    void setWordWrap(bool state);
 
 Q_SIGNALS:
     void checkSyntax();
@@ -132,4 +132,3 @@ private:
     bool mDebug = false;
 };
 }
-
