@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef SIEVETEXTEDITORSPELLCHECKDECORATOR_H
-#define SIEVETEXTEDITORSPELLCHECKDECORATOR_H
+#pragma once
 
 #include <sonnet/spellcheckdecorator.h>
 
@@ -23,4 +22,3 @@ private:
     SieveTextEdit *const mPlainTextEdit;
 };
 }
-#endif // SIEVETEXTEDITORSPELLCHECKDECORATOR_H
