@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -13,9 +13,7 @@ CheckScriptJobTest::CheckScriptJobTest(QObject *parent)
 {
 }
 
-CheckScriptJobTest::~CheckScriptJobTest()
-{
-}
+CheckScriptJobTest::~CheckScriptJobTest() = default;
 
 void CheckScriptJobTest::canBeStarted()
 {
